@@ -29,6 +29,7 @@ __copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc." \
                 "Copyright (c) 2012 Igalia, S.L."
 __license__   = "LGPL"
 
+import importlib
 import os
 import pyatspi
 import re
@@ -262,6 +263,7 @@ def _processKeyboardEvent(event):
             _createOrcaXmodmap()
             _restoreOrcaKeys = False
     elif not keyboardEvent.isModifierKey():
+        _orcaModifierPressed = False
         orca_state.bypassNextCommand = False
  
     return isOrcaModifier or orca_state.learnModeEnabled
@@ -484,10 +486,7 @@ def showAppPreferencesGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = __import__(settings.appGuiPreferencesModule,
-                            globals(),
-                            locals(),
-                            [''])
+        module = importlib.import_module('.app_gui_prefs', 'orca')
         module.showPreferencesUI()
     except:
         debug.printException(debug.LEVEL_SEVERE)
@@ -502,10 +501,7 @@ def showPreferencesGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = __import__(settings.guiPreferencesModule,
-                            globals(),
-                            locals(),
-                            [''])
+        module = importlib.import_module('.orca_gui_prefs', 'orca')
         module.showPreferencesUI()
     except:
         debug.printException(debug.LEVEL_SEVERE)
@@ -519,10 +515,7 @@ def showMainWindowGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = __import__(settings.mainWindowModule,
-                            globals(),
-                            locals(),
-                            [''])
+        module = importlib.import_module('.orca_gui_main', 'orca')
         if settings.showMainWindow or settings.overrideDisabledMainWindow:
             module.showMainUI()
         else:
@@ -724,10 +717,7 @@ def quitOrca(script=None, inputEvent=None):
         shutdown()
     else:
         try:
-            module = __import__(settings.quitModule,
-                                globals(),
-                                locals(),
-                                [''])
+            module = importlib.import_module('.orca_gui_quit', 'orca')
             module.showQuitUI()
         except:
             debug.printException(debug.LEVEL_SEVERE)
@@ -741,10 +731,7 @@ def showFindGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = __import__(settings.findModule,
-                            globals(),
-                            locals(),
-                            [''])
+        module = importlib.import_module('.orca_gui_find', 'orca')
         module.showFindUI()
     except:
         debug.printException(debug.LEVEL_SEVERE)
@@ -756,10 +743,7 @@ def showSplashGUI(script=None, inputEvent=None):
     """
 
     try:
-        module = __import__(settings.splashModule,
-                            globals(),
-                            locals(),
-                            [''])
+        module = importlib.import_module('.orca_gui_splash', 'orca')
         if _settingsManager.getSetting("showSplashWindow"):
             module.showSplashUI()
         else:
